# `splendaq`

[![Python package](https://github.com/splendor-collab/splendaq/actions/workflows/python-package.yml/badge.svg)](https://github.com/splendor-collab/splendaq/actions/workflows/python-package.yml) [![PyPI](https://img.shields.io/pypi/v/splendaq)](https://pypi.org/project/splendaq/) [![Python 3.6](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/release/python-360/) [![GitHub](https://img.shields.io/github/license/splendor-collab/splendaq)](https://github.com/splendor-collab/splendaq/blob/main/LICENSE) [![arXiv](https://img.shields.io/badge/arXiv-2310.01279-<COLOR>.svg)](https://arxiv.org/abs/2310.01279)


Package for general data acquisition with a focus on the Moku device by [Liquid Instruments](https://www.liquidinstruments.com/).

If you use this package for your research, please cite our paper as below:
```
@article{Watkins:2023rgt,
    author = "Watkins, Samuel L.",
    title = "{SPLENDAQ: A Detector-Agnostic Data Acquisition System for Small-Scale Physics Experiments}",
    eprint = "2310.01279",
    archivePrefix = "arXiv",
    primaryClass = "physics.ins-det",
    reportNumber = "LA-UR-23-31174",
    doi = "10.1007/s10909-023-03021-w",
    journal = "J. Low Temp. Phys.",
    volume = "214",
    number = "3-4",
    pages = "133--142",
    year = "2024"
}
```
